@@ -29,6 +29,8 @@ class EcdnClient(AbstractClient):
     def AddEcdnDomain(self, request):
         """本接口（AddEcdnDomain）用于创建加速域名。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/41123"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for AddEcdnDomain.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.AddEcdnDomainRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.AddEcdnDomainResponse`
@@ -85,6 +87,8 @@ class EcdnClient(AbstractClient):
     def DeleteEcdnDomain(self, request):
         """本接口（DeleteEcdnDomain）用于删除指定加速域名。待删除域名必须处于已停用状态。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/570/42471"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for DeleteEcdnDomain.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DeleteEcdnDomainRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DeleteEcdnDomainResponse`
@@ -113,6 +117,8 @@ class EcdnClient(AbstractClient):
     def DescribeDomains(self, request):
         """本接口（DescribeDomains）用于查询CDN域名基本信息，包括项目id，状态，业务类型，创建时间，更新时间等。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/41118"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for DescribeDomains.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribeDomainsRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DescribeDomainsResponse`
@@ -141,6 +147,8 @@ class EcdnClient(AbstractClient):
     def DescribeDomainsConfig(self, request):
         """本接口（DescribeDomainsConfig）用于查询CDN加速域名详细配置信息。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/41117"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for DescribeDomainsConfig.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribeDomainsConfigRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DescribeDomainsConfigResponse`
@@ -291,6 +299,8 @@ class EcdnClient(AbstractClient):
     def DescribePurgeQuota(self, request):
         """查询刷新接口的用量配额。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/41956"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for DescribePurgeQuota.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeQuotaRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeQuotaResponse`
@@ -319,6 +329,8 @@ class EcdnClient(AbstractClient):
     def DescribePurgeTasks(self, request):
         """DescribePurgeTasks 用于查询刷新任务提交历史记录及执行进度。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/37873"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for DescribePurgeTasks.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeTasksRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.DescribePurgeTasksResponse`
@@ -347,6 +359,8 @@ class EcdnClient(AbstractClient):
     def PurgePathCache(self, request):
         """PurgePathCache 用于批量刷新目录缓存，一次提交将返回一个刷新任务id。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="	https://cloud.tencent.com/document/api/570/42475"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for PurgePathCache.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.PurgePathCacheRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.PurgePathCacheResponse`
@@ -375,6 +389,8 @@ class EcdnClient(AbstractClient):
     def PurgeUrlsCache(self, request):
         """PurgeUrlsCache 用于批量刷新Url，一次提交将返回一个刷新任务id。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/api/228/37870"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for PurgeUrlsCache.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.PurgeUrlsCacheRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.PurgeUrlsCacheResponse`
@@ -403,6 +419,8 @@ class EcdnClient(AbstractClient):
     def StartEcdnDomain(self, request):
         """本接口（StartEcdnDomain）用于启用加速域名，待启用域名必须处于已下线状态。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/product/228/41121"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for StartEcdnDomain.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.StartEcdnDomainRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.StartEcdnDomainResponse`
@@ -431,6 +449,8 @@ class EcdnClient(AbstractClient):
     def StopEcdnDomain(self, request):
         """本接口（StopCdnDomain）用于停止加速域名，待停用加速域名必须处于已上线或部署中状态。
 
+        >?  若您的业务已迁移至 CDN 控制台，请参考<a href="https://cloud.tencent.com/document/product/228/41120"> CDN 接口文档</a>，使用  CDN 相关API 进行操作。
+
         :param request: Request instance for StopEcdnDomain.
         :type request: :class:`tencentcloud.ecdn.v20191012.models.StopEcdnDomainRequest`
         :rtype: :class:`tencentcloud.ecdn.v20191012.models.StopEcdnDomainResponse`
